import FreeCADGui as Gui
import FreeCAD as App
import os
import time

from kipy import KiCad

from . import settings

from .api import API
from .copper import Copper
from .board import Board
from .parts import Parts

class Project:
    def __init__(self):
        start_time = time.time()
        self.board = None
        self.kicad_api = None
        self.kicad_project = None
        self.viewprovider = None

        feature = App.ActiveDocument.addObject('App::Part', 'KiConnect')
        self.feature = feature

        feature.addProperty('App::PropertyTime', 'ProcessTime', 'KiConnect', 'Time to process Project', hidden=True, read_only=True)

        self.API = API()
        self.feature.addObject(self.API.feature)

        if self.API.is_connected:
            kicad_board = self.API.kicad.get_board()

            self.board = Board(kicad_board)
            self.feature.addObject(self.board.feature)

            self.parts = Parts(kicad_board, self.board)
            self.board.feature.addObject(self.parts.feature)

            self.copper = Copper(kicad_board, self.board)
            self.board.feature.addObject(self.copper.feature)

        feature.ProcessTime = time.time() - start_time
